@@ -128,9 +128,9 @@ test_that("single-row data.frames with rownames can be converted", {
 
 test_that("Time zones are respected if available", {
   skip_if_no_pandas()
-  
+
   pd <- import("pandas", convert = FALSE)
-  
+
   before <- pd$DataFrame(list('TZ' = pd$Series(
     c(
       pd$Timestamp('20130102003020', tz = 'US/Pacific'),
@@ -139,59 +139,83 @@ test_that("Time zones are respected if available", {
       pd$Timestamp('20130102003020', tz = 'Hongkong')
     )
   )))
-  
+
   converted <- py_to_r(before)
   after <- r_to_py(converted)
-  
+
   # check if both are the same in *local* timezone
   expect_equal(py_to_r(before), py_to_r(after))
-  
+
 })
 
 test_that("NaT is converted to NA", {
   skip_if_no_pandas()
-  
+
   pd <- import("pandas", convert = FALSE)
   np <- import("numpy")
-  
+
   before <- pd$DataFrame(pd$Series(
     c(
       pd$Timestamp(NULL),
       pd$Timestamp(np$nan)
     )
   ))
-  
+
   converted <- py_to_r(before)
   after <- r_to_py(converted)
 
   expect_equal(py_to_r(before), py_to_r(after))
-  
+
 })
 
 test_that("pandas NAs are converted to R NAs", {
   skip_if_no_pandas()
-  
-  pd <- import("pandas", convert = FALSE)
-  
-  py_run_string("
+
+  code <- "
 import pandas as pd
 df = pd.DataFrame({'a': [1, 2, 3], 'b': [10, 20, pd.NA]})
-")
-  
-  expect_true(is.na(py$df$b[3]))
-  
+"
+
+  locals <- py_run_string(code, local = TRUE, convert = TRUE)
+
+  df <- locals$df
+  expect_true(is.na(df$b[[3]]))
+
+  pd <- import("pandas", convert = FALSE)
   pdNA <- py_to_r(py_get_attr(pd, "NA"))
   expect_true(is.na(pdNA))
-  
+
 })
 
 test_that("categorical NAs are handled", {
   skip_if_no_pandas()
-  
+
   df <- data.frame(x = factor("a", NA))
   pdf <- r_to_py(df)
   rdf <- py_to_r(pdf)
   attr(rdf, "pandas.index") <- NULL
   expect_equal(df, rdf)
-  
+
+})
+
+
+
+test_that("ordered categoricals are handled correctly, #1234", {
+  skip_if_no_pandas()
+
+  p_df <- py_run_string(
+'import pandas as pd
+
+# Create Dataframe with Unordered & Ordered Factors
+df = pd.DataFrame({"FCT": pd.Categorical(["No", "Yes"]),
+                   "ORD": pd.Categorical(["No", "Yes"], ordered=True)})
+', local = TRUE)$df
+
+  r_df <- data.frame("FCT" = factor(c("No", "Yes")),
+                     "ORD" = factor(c("No", "Yes"), ordered = TRUE))
+
+  attr(p_df, "pandas.index") <- NULL
+
+  expect_identical(p_df, r_df)
+
 })
