@@ -8,5 +8,10 @@ test_that("Objects can be saved and loaded with pickle", {
   py_save_object(x, "x.pickle")
   on.exit(unlink("x.pickle"), add = TRUE)
   y <- py_load_object("x.pickle")
-  expect_true(x == y)
+  expect_identical(y, list(a = 1, b = 2))
+  expect_true(py_bool(x == y))
+  y <- py_load_object("x.pickle", convert = FALSE)
+  expect_s3_class(y, "python.builtin.dict")
+  expect_true(py_to_r(x == y))
 })
+
